<?php

/**
 * Stencil Pro functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Stencil Pro
 */

/**
 * Stencil Pro only works in WordPress 4.7 or later.
 */
if (version_compare($GLOBALS['wp_version'], '4.7', '<')) {
    require get_template_directory() . '/inc/back-compat.php';
    return;
}

if (!function_exists('stencil_setup')) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function stencil_setup() {
        /*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on _s, use a find and replace
		 * to change 'stencil-pro' to the name of your theme in all the template files.
		 */
        load_theme_textdomain('stencil-pro', get_template_directory() . '/languages');

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
        add_theme_support('title-tag');

        /*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
        add_theme_support('post-thumbnails');
        add_image_size('stencil-first-post', 1152, 680, true);

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'menu-1' => esc_html__('Primary', 'stencil-pro'),
            'social' => esc_html__('Social', 'stencil-pro'),
        ));

        /*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support(
            'custom-logo',
            array(
                'height'      => 320,
                'width'       => 190,
                'flex-width'  => true,
                'flex-height' => true,
            )
        );

        // Add support for Block Styles.
        add_theme_support('wp-block-styles');

        // Add support for full and wide align images.
        // add_theme_support( 'align-wide' );

        // Add support for editor styles.
        add_theme_support('editor-styles');

        // Enqueue editor styles.
        add_editor_style('style-editor.css');

        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('stencil_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        // Add support for responsive embeds.
        add_theme_support('responsive-embeds');

        // Enable layouts extensions.
        add_theme_support(
            'theme-layouts',
            array(
                'full-width'    => esc_html__('Full width', 'stencil-pro'),
                'right-sidebar' => esc_html__('Right sidebar', 'stencil-pro'),
                'left-sidebar'  => esc_html__('Left sidebar', 'stencil-pro')
            ),
            array('customize' => false, 'default' => 'right-sidebar')
        );

        // Disable Kirkir telemetry
        add_filter('kirki_telemetry', '__return_false');
    }
endif;
add_action('after_setup_theme', 'stencil_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function stencil_content_width() {
    // This variable is intended to be overruled from themes.
    // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
    // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
    $GLOBALS['content_width'] = apply_filters('stencil_content_width', 1152);
}
add_action('after_setup_theme', 'stencil_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function stencil_sidebar_init() {
    register_sidebar(array(
        'name'          => esc_html__('Sidebar', 'stencil-pro'),
        'id'            => 'sidebar-1',
        'description'   => esc_html__('Add widgets here.', 'stencil-pro'),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h2 class="widget__title">',
        'after_title'   => '</h2>',
    ));
}
add_action('widgets_init', 'stencil_sidebar_init');

/**
 * Enqueue scripts and styles.
 */
function stencil_scripts() {

    wp_enqueue_style('stencil-fonts', stencil_fonts_url(), array(), null);

    wp_enqueue_style('stencil-style', get_stylesheet_uri(), array(), wp_get_theme()->get('Version'));

    wp_enqueue_style('stencil-tiny-slider-css', get_template_directory_uri() . '/assets/css/tiny-slider.css', array(), wp_get_theme()->get('Version'));

    wp_enqueue_script('stencil-navigation', get_theme_file_uri('/assets/js/navigation.js'), array(), '1.0.0', true);

    wp_enqueue_script('stencil-skip-link-focus-fix', get_theme_file_uri('/assets/js/skip-link-focus-fix.js'), array(), '1.0.0', true);

    wp_enqueue_script('stencil-tiny-slider-js', get_theme_file_uri('/assets/js/tiny-slider.js'), array('jquery'), '1.0.0', true);

    wp_enqueue_script('stencil-custom-js', get_theme_file_uri('/assets/js/custom.js'), array('jquery'), '1.0.0', true);

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}
add_action('wp_enqueue_scripts', 'stencil_scripts');

/**
 * Register custom fonts.
 */
function stencil_fonts_url() {
    $fonts_url = '';

    /*
	 * Translators: If there are characters in your language that are not
	 * supported by Amiri, translate this to 'off'. Do not translate
	 * into your own language.
	 */
    $amiri = _x('on', 'Amiri font: on or off', 'stencil-pro');

    if ('off' !== $amiri) {
        $font_families = array();

        $font_families[] = 'Amiri:400,400i,700,700i';

        $query_args = array(
            'family' => urlencode(implode('|', $font_families)),
            'subset' => urlencode('latin,latin-ext'),
        );

        $fonts_url = add_query_arg($query_args, 'https://fonts.googleapis.com/css');
    }

    return esc_url_raw($fonts_url);
}

/**
 * Re-set default image sizes
 */
function stencil_reset_default_image_sizes() {

    // 'large' size: featured slider
    update_option('large_size_w', 1152);
    update_option('large_size_h', 580);
    update_option('large_crop', 1);

    // 'medium' size: blog, grid, list
    update_option('medium_size_w', 520);
    update_option('medium_size_h', 410);
    update_option('medium_crop', 1);
}
add_action('after_switch_theme', 'stencil_reset_default_image_sizes');

/**
 * Registers custom widgets.
 *
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function stencil_widgets_init() {

    require get_template_directory() . '/inc/widgets/about-me.php';
    register_widget('Stencil_Pro_About_Widget');

    require get_template_directory() . '/inc/widgets/facebook.php';
    register_widget('Stencil_Pro_Facebook_Widget');

    require get_template_directory() . '/inc/widgets/flickr.php';
    register_widget('Stencil_Pro_Flickr_Widget');

    require get_template_directory() . '/inc/widgets/recent-posts.php';
    register_widget('Stencil_Pro_Recent_Posts_Widget');

    require get_template_directory() . '/inc/widgets/twitter.php';
    register_widget('Stencil_Pro_Twitter_Widget');

    require get_template_directory() . '/inc/widgets/video.php';
    register_widget('Stencil_Pro_Video_Widget');
}
add_action('widgets_init', 'stencil_widgets_init');

/**
 * Implement the Custom Header feature.
 */
// require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * SVG Icons related functions.
 */
require get_template_directory() . '/inc/classes/class-svg-icons.php';
require get_template_directory() . '/inc/icon-functions.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
    require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load Kirki compatibility file.
 */
require get_template_directory() . '/inc/extensions/kirki/kirki.php';
require get_template_directory() . '/inc/customizer/helpers.php';
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Demo importer
 */
require trailingslashit(get_template_directory()) . 'inc/demo/demo-importer.php';

/**
 * Post/page layout
 */
require trailingslashit(get_template_directory()) . 'inc/extensions/layouts.php';
